imputeCensored(data = NULL, estimator = lm, epsilon = 0.1, maxit = 1000)input.predict along
with new data. Default "loriginal_data member.epsilon or more than maxit iterations have
been performed.It is up to the user to check whether the imputed values make sense. In particular, for solver runtime data and timeouts one would expect that the imputed values are above the timeout threshold, indicating at what time the algorithms that have timed out would have solved the problem. No effort is made to enforce such application-specific constraints.
data(satsolvers)
imputed = imputeCensored(satsolvers)Run the code above in your browser using DataLab